pub(crate) struct PhantomDrop<T>(PhantomData<T>);Expand description
A cute utility type that works just like PhantomData, but also
implements Drop. This forces any lifetimes that are associated
with the type to be used until the Drop impl is ran. This prevents
lifetimes from being shortened.
Tuple Fields
0: PhantomData<T>Trait Implementations
Sourceimpl<T: Debug> Debug for PhantomDrop<T>
impl<T: Debug> Debug for PhantomDrop<T>
Sourceimpl<T> Default for PhantomDrop<T>
impl<T> Default for PhantomDrop<T>