struct ErrorSinkRaw {
scopes: HashMap<ThreadId, Vec<ErrorScope>>,
uncaptured_handler: Option<Arc<dyn UncapturedErrorHandler>>,
}Available on
wgpu_core only.Fields
scopes: HashMap<ThreadId, Vec<ErrorScope>>uncaptured_handler: Option<Arc<dyn UncapturedErrorHandler>>Implementations
Sourceimpl ErrorSinkRaw
impl ErrorSinkRaw
fn new() -> ErrorSinkRaw
Sourcefn handle_error_or_return_handler(
&mut self,
err: Error,
) -> Option<impl FnOnce()>
fn handle_error_or_return_handler( &mut self, err: Error, ) -> Option<impl FnOnce()>
Deliver the error to
- the innermost error scope, if any, or
- the uncaptured error handler, if there is one, or
default_error_handler().
If a closure is returned, the caller should call it immediately after dropping the
ErrorSink mutex guard. This makes sure that the user callback is not called with
a wgpu mutex held.