macro_rules! explicit_send_sync_impl {
($name:ident) => { ... };
}Expand description
Generates a Send and Sync implementation for a dispatch enum generated by dispatch_types!.
macro_rules! explicit_send_sync_impl {
($name:ident) => { ... };
}Generates a Send and Sync implementation for a dispatch enum generated by dispatch_types!.