Struct wgpu::hal::BindGroupDescriptor
source · pub struct BindGroupDescriptor<'a, A>where
A: Api,{
pub label: Option<&'a str>,
pub layout: &'a <A as Api>::BindGroupLayout,
pub buffers: &'a [BufferBinding<'a, A>],
pub samplers: &'a [&'a <A as Api>::Sampler],
pub textures: &'a [TextureBinding<'a, A>],
pub entries: &'a [BindGroupEntry],
pub acceleration_structures: &'a [&'a <A as Api>::AccelerationStructure],
}Available on
wgpu_core only.Expand description
BindGroup descriptor.
Valid usage:
. - entries has to be sorted by ascending BindGroupEntry::binding
. - entries has to have the same set of BindGroupEntry::binding as layout
. - each entry has to be compatible with the layout
. - each entry’s BindGroupEntry::resource_index is within range
of the corresponding resource array, selected by the relevant
BindGroupLayoutEntry.
Fields
label: Option<&'a str>layout: &'a <A as Api>::BindGroupLayoutbuffers: &'a [BufferBinding<'a, A>]samplers: &'a [&'a <A as Api>::Sampler]textures: &'a [TextureBinding<'a, A>]entries: &'a [BindGroupEntry]acceleration_structures: &'a [&'a <A as Api>::AccelerationStructure]Trait Implementations
sourceimpl<'a, A> Clone for BindGroupDescriptor<'a, A>
impl<'a, A> Clone for BindGroupDescriptor<'a, A>
sourcefn clone(&self) -> BindGroupDescriptor<'a, A>
fn clone(&self) -> BindGroupDescriptor<'a, A>
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl<'a, A> Debug for BindGroupDescriptor<'a, A>
impl<'a, A> Debug for BindGroupDescriptor<'a, A>