BlasAabbGeometry

Struct BlasAabbGeometry 

pub struct BlasAabbGeometry<'a> {
    pub size: &'a BlasAABBGeometrySizeDescriptor,
    pub stride: BufferAddress,
    pub aabb_buffer: &'a Buffer,
    pub primitive_offset: u32,
}
Definition for an axis-aligned bounding box geometry group for a bottom level acceleration structure.

Buffer data must contain size.primitive_count primitives at primitive_offset, each size.stride bytes, with stride at least AABB_GEOMETRY_MIN_STRIDE and a multiple of 8.

Fields

size: &'a BlasAABBGeometrySizeDescriptor

Sub descriptor for the size defining attributes of this geometry.

stride: BufferAddress

Stride in bytes between consecutive AABB primitives in the buffer (at least AABB_GEOMETRY_MIN_STRIDE, and must be a multiple of 8).

aabb_buffer: &'a Buffer

Buffer containing packed AABB primitives (layout determined by size.stride).

primitive_offset: u32

Byte offset to the first AABB primitive (must be a multiple of 8).