#[repr(C)]pub struct DepthStencilState {
pub format: TextureFormat,
pub depth_write_enabled: Option<bool>,
pub depth_compare: Option<CompareFunction>,
pub stencil: StencilState,
pub bias: DepthBiasState,
}Expand description
Describes the depth/stencil state in a render pipeline.
Corresponds to WebGPU GPUDepthStencilState.
Fields
format: TextureFormatFormat of the depth/stencil buffer, must be special depth format. Must match the format
of the depth/stencil attachment in CommandEncoder::begin_render_pass.
depth_write_enabled: Option<bool>If disabled, depth will not be written to. Must be Some if format is
a depth format.
depth_compare: Option<CompareFunction>Comparison function used to compare depth values in the depth test.
Must be Some if depth_write_enabled is true or either stencil face
depth_fail_op is not Keep.
stencil: StencilStateStencil state.
bias: DepthBiasStateDepth bias state.
Implementations
Sourceimpl DepthStencilState
impl DepthStencilState
Sourcepub fn stencil(
format: TextureFormat,
stencil: StencilState,
) -> DepthStencilState
pub fn stencil( format: TextureFormat, stencil: StencilState, ) -> DepthStencilState
Construct DepthStencilState for a stencil operation with no depth operation.
Panics if format does not have a stencil aspect.
Sourcepub fn is_depth_enabled(&self) -> bool
pub fn is_depth_enabled(&self) -> bool
Returns true if the depth testing is enabled.
Sourcepub fn is_depth_read_only(&self) -> bool
pub fn is_depth_read_only(&self) -> bool
Returns true if the state doesn’t mutate the depth buffer.
Sourcepub fn is_stencil_read_only(&self, cull_mode: Option<Face>) -> bool
pub fn is_stencil_read_only(&self, cull_mode: Option<Face>) -> bool
Returns true if the state doesn’t mutate the stencil.
Sourcepub fn is_read_only(&self, cull_mode: Option<Face>) -> bool
pub fn is_read_only(&self, cull_mode: Option<Face>) -> bool
Returns true if the state doesn’t mutate either depth or stencil of the target.