Struct ExperimentalFeatures
pub struct ExperimentalFeatures {
enabled: bool,
}Expand description
Token of the user agreeing to access experimental features.
Fields
enabled: boolImplementations
impl ExperimentalFeatures
impl ExperimentalFeatures
pub const fn default() -> ExperimentalFeatures
pub const fn default() -> ExperimentalFeatures
This function is identical to Default::default() except that it is a const fn.
impl ExperimentalFeatures
impl ExperimentalFeatures
pub const fn disabled() -> ExperimentalFeatures
pub const fn disabled() -> ExperimentalFeatures
Uses of Features prefixed with “EXPERIMENTAL” are disallowed.
pub const unsafe fn enabled() -> ExperimentalFeatures
pub const unsafe fn enabled() -> ExperimentalFeatures
Uses of Features prefixed with “EXPERIMENTAL” may result
in undefined behavior when used incorrectly. The exact bounds
of these issues varies by the feature. These instances are
inherently bugs in our implementation that we will eventually fix.
By giving access to still work-in-progress APIs, users can get access to newer technology sooner, and we can work with users to fix bugs quicker.
Look inside our repo at the api-specs for more information
on various experimental apis.
Safety
- You acknowledge that there may be UB-containing bugs in these apis and those may be hit by calling otherwise safe code.
- You agree to report any such bugs to us, if you find them.
pub const fn is_enabled(&self) -> bool
pub const fn is_enabled(&self) -> bool
Returns true if the user has agreed to access experimental features.