Struct ForceShaderModelToken
pub struct ForceShaderModelToken {
inner: Option<DxcShaderModel>,
}Expand description
Used to force wgpu to expose certain features on passthrough shaders even when those features aren’t present on runtime-compiled shaders
Fields
inner: Option<DxcShaderModel>Implementations
impl ForceShaderModelToken
impl ForceShaderModelToken
pub const fn default() -> ForceShaderModelToken
pub const fn default() -> ForceShaderModelToken
This function is identical to Default::default() except that it is a const fn.
impl ForceShaderModelToken
impl ForceShaderModelToken
pub const unsafe fn with_shader_model(
sm: DxcShaderModel,
) -> ForceShaderModelToken
pub const unsafe fn with_shader_model( sm: DxcShaderModel, ) -> ForceShaderModelToken
Creates an unsafe token, opting you in to seeing features that you may not necessarily use on standard runtime-compiled shaders.
Safety
Do not make use in runtime-compiled shaders of any features that may not be supported by the FXC or DXC version you use.
pub const fn get(&self) -> Option<DxcShaderModel>
pub const fn get(&self) -> Option<DxcShaderModel>
Returns the shader model version, if any, in this token.