Struct NoopBackendOptions
pub struct NoopBackendOptions {
pub enable: bool,
pub limits: Option<Limits>,
pub features: Option<Features>,
pub device_type: Option<DeviceType>,
pub subgroup_min_size: Option<u32>,
pub subgroup_max_size: Option<u32>,
}Expand description
Configuration for the noop backend.
Part of BackendOptions.
Fields
enable: boolWhether to allow the noop backend to be used.
The noop backend stubs out all operations except for buffer creation and mapping, so it must not be used when not expected. Therefore, it will not be used unless explicitly enabled.
limits: Option<Limits>Specify the reported limits values. If None, reports maximally permissive limits.
features: Option<Features>Specify the reported feature support. If None, reports support for all features.
device_type: Option<DeviceType>Specify the reported device type. If None, uses crate::DeviceType::Other.
subgroup_min_size: Option<u32>Specify the reported minimum subgroup size.
subgroup_max_size: Option<u32>Specify the reported maximum subgroup size.
Implementations
impl NoopBackendOptions
impl NoopBackendOptions
pub fn enabled() -> NoopBackendOptions
pub fn enabled() -> NoopBackendOptions
Enable the noop backend.
pub fn from_env_or_default() -> NoopBackendOptions
pub fn from_env_or_default() -> NoopBackendOptions
Choose whether the noop backend is enabled from the environment.
It will be enabled if the environment variable WGPU_NOOP_BACKEND has the value 1
and not otherwise. Future versions may assign other meanings to other values.
pub fn with_env(self) -> NoopBackendOptions
pub fn with_env(self) -> NoopBackendOptions
Takes the given options, modifies them based on the environment variables, and returns the result.
See from_env_or_default() for the interpretation.