QueueWriteBufferView

Struct QueueWriteBufferView 

pub struct QueueWriteBufferView {
    queue: Queue,
    buffer: Buffer,
    offset: BufferAddress,
    inner: DispatchQueueWriteBuffer,
}
A write-only view into a staging buffer.

This type is what Queue::write_buffer_with() returns.

Fields

queue: Queuebuffer: Bufferoffset: BufferAddressinner: DispatchQueueWriteBuffer

Implementations

Source

impl QueueWriteBufferView

pub fn as_custom<T: QueueWriteBufferInterface>(&self) -> Option<&T>

Available on custom only.

Returns custom implementation of QueueWriteBufferView (if custom backend and is internally T)

Source

impl QueueWriteBufferView

These methods are equivalent to the methods of the same names on WriteOnly.

pub fn len(&self) -> usize

Returns the length of this view; the number of bytes to be written.

pub fn is_empty(&self) -> bool

Returns true if the view has a length of 0.

pub fn slice<'a, S: RangeBounds<usize>>( &'a mut self, bounds: S, ) -> WriteOnly<'a, [u8]>

Returns a WriteOnly reference to a portion of this.

.slice(..) can be used to access the whole data.

pub fn copy_from_slice(&mut self, src: &[u8])

Copies all elements from src into self.

The length of src must be the same as self.

This method is equivalent to self.slice(..).copy_from_slice(src).