pub struct RenderBundle { /* private fields */ }Expand description
Pre-prepared reusable bundle of GPU operations.
It only supports a handful of render commands, but it makes them reusable. Executing a
RenderBundle is often more efficient than issuing the underlying commands manually.
It can be created by use of a RenderBundleEncoder, and executed onto a CommandEncoder
using RenderPass::execute_bundles.
Corresponds to WebGPU GPURenderBundle.
Implementations
Sourceimpl RenderBundle
impl RenderBundle
Sourcepub fn as_custom<T: RenderBundleInterface>(&self) -> Option<&T>
Available on custom only.
pub fn as_custom<T: RenderBundleInterface>(&self) -> Option<&T>
custom only.Returns custom implementation of RenderBundle (if custom backend and is internally T)