Struct wgpu::RenderPassDescriptor [−][src]
pub struct RenderPassDescriptor<'a, 'b> {
pub label: Label<'a>,
pub color_attachments: &'b [RenderPassColorAttachment<'a>],
pub depth_stencil_attachment: Option<RenderPassDepthStencilAttachment<'a>>,
}Describes the attachments of a render pass.
Note: separate lifetimes are needed because the texture views have to live as long as the pass is recorded, while everything else doesn’t.
Fields
label: Label<'a>Debug label of the render pass. This will show up in graphics debuggers for easy identification.
color_attachments: &'b [RenderPassColorAttachment<'a>]The color attachments of the render pass.
depth_stencil_attachment: Option<RenderPassDepthStencilAttachment<'a>>The depth and stencil attachment of the render pass, if any.