pub struct RenderPipeline { /* private fields */ }Expand description
Handle to a rendering (graphics) pipeline.
A RenderPipeline object represents a graphics pipeline and its stages, bindings, vertex
buffers and targets. It can be created with Device::create_render_pipeline.
Corresponds to WebGPU GPURenderPipeline.
Implementations
Sourceimpl RenderPipeline
impl RenderPipeline
Sourcepub fn get_bind_group_layout(&self, index: u32) -> BindGroupLayout
pub fn get_bind_group_layout(&self, index: u32) -> BindGroupLayout
Get an object representing the bind group layout at a given index.
If this pipeline was created with a default layout, then
bind groups created with the returned BindGroupLayout can only be used with this pipeline.
This method will raise a validation error if there is no bind group layout at index.
Sourcepub fn as_custom<T: RenderPipelineInterface>(&self) -> Option<&T>
Available on custom only.
pub fn as_custom<T: RenderPipelineInterface>(&self) -> Option<&T>
custom only.Returns custom implementation of RenderPipeline (if custom backend and is internally T)