#[repr(C)]pub struct RequestAdapterOptionsBase<S> {
pub power_preference: PowerPreference,
pub force_fallback_adapter: bool,
pub compatible_surface: Option<S>,
pub apply_limit_buckets: bool,
}Expand description
Options for requesting adapter.
Corresponds to WebGPU GPURequestAdapterOptions,
with some wgpu extensions.
Fields
power_preference: PowerPreferencePower preference for the adapter.
force_fallback_adapter: boolIndicates that only a fallback adapter can be returned. This is generally a “software” implementation on the system.
compatible_surface: Option<S>Surface that is required to be presentable with the requested adapter. This does not create the surface, only guarantees that the adapter can present to said surface. For WebGL, this is strictly required, as an adapter can not be created without a surface.
apply_limit_buckets: boolRequests that the returned adapter’s limits are mapped to one of several pre-defined
buckets, as described in limit bucketing. If your application exposes wgpu to untrusted
content (e.g. a web browser), this can reduce the potential for fingerprinting via adapter
characteristics.
To be effective, control of this option must not be available to the untrusted content. Instead, set this option unconditionally in trusted code.