Struct SurfaceColorSpaces
#[repr(transparent)]pub struct SurfaceColorSpaces(<SurfaceColorSpaces as PublicFlags>::Internal);Expand description
A set of SurfaceColorSpaces supported by a surface for a particular
texture format.
Reported per format in SurfaceCapabilities::formats via
SurfaceFormatCapabilities.
Tuple Fields
0: <SurfaceColorSpaces as PublicFlags>::InternalImplementations
impl SurfaceColorSpaces
impl SurfaceColorSpaces
pub const SRGB: SurfaceColorSpaces
pub const SRGB: SurfaceColorSpaces
SurfaceColorSpace::Srgb is supported.
pub const EXTENDED_SRGB_LINEAR: SurfaceColorSpaces
pub const EXTENDED_SRGB_LINEAR: SurfaceColorSpaces
SurfaceColorSpace::ExtendedSrgbLinear is supported.
pub const DISPLAY_P3: SurfaceColorSpaces
pub const DISPLAY_P3: SurfaceColorSpaces
SurfaceColorSpace::DisplayP3 is supported.
pub const BT2100_PQ: SurfaceColorSpaces
pub const BT2100_PQ: SurfaceColorSpaces
SurfaceColorSpace::Bt2100Pq is supported.
pub const BT2100_HLG: SurfaceColorSpaces
pub const BT2100_HLG: SurfaceColorSpaces
SurfaceColorSpace::Bt2100Hlg is supported.
pub const EXTENDED_SRGB: SurfaceColorSpaces
pub const EXTENDED_SRGB: SurfaceColorSpaces
SurfaceColorSpace::ExtendedSrgb is supported.
pub const EXTENDED_DISPLAY_P3: SurfaceColorSpaces
pub const EXTENDED_DISPLAY_P3: SurfaceColorSpaces
SurfaceColorSpace::ExtendedDisplayP3 is supported.
impl SurfaceColorSpaces
impl SurfaceColorSpaces
pub const fn empty() -> SurfaceColorSpaces
pub const fn empty() -> SurfaceColorSpaces
Get a flags value with all bits unset.
pub const fn all() -> SurfaceColorSpaces
pub const fn all() -> SurfaceColorSpaces
Get a flags value with all known bits set.
pub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u32) -> Option<SurfaceColorSpaces>
pub const fn from_bits(bits: u32) -> Option<SurfaceColorSpaces>
Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u32) -> SurfaceColorSpaces
pub const fn from_bits_truncate(bits: u32) -> SurfaceColorSpaces
Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u32) -> SurfaceColorSpaces
pub const fn from_bits_retain(bits: u32) -> SurfaceColorSpaces
Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<SurfaceColorSpaces>
pub fn from_name(name: &str) -> Option<SurfaceColorSpaces>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn intersects(&self, other: SurfaceColorSpaces) -> bool
pub const fn intersects(&self, other: SurfaceColorSpaces) -> bool
Whether any set bits in other are also set in self.
pub const fn contains(&self, other: SurfaceColorSpaces) -> bool
pub const fn contains(&self, other: SurfaceColorSpaces) -> bool
Whether all set bits in other are also set in self.
pub fn insert(&mut self, other: SurfaceColorSpaces)
pub fn insert(&mut self, other: SurfaceColorSpaces)
The bitwise or (|) of the bits in self and other.
pub fn remove(&mut self, other: SurfaceColorSpaces)
pub fn remove(&mut self, other: SurfaceColorSpaces)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn toggle(&mut self, other: SurfaceColorSpaces)
pub fn toggle(&mut self, other: SurfaceColorSpaces)
The bitwise exclusive-or (^) of the bits in self and other.
pub fn set(&mut self, other: SurfaceColorSpaces, value: bool)
pub fn set(&mut self, other: SurfaceColorSpaces, value: bool)
Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: SurfaceColorSpaces) -> SurfaceColorSpaces
pub const fn intersection(self, other: SurfaceColorSpaces) -> SurfaceColorSpaces
The bitwise and (&) of the bits in self and other.
pub const fn union(self, other: SurfaceColorSpaces) -> SurfaceColorSpaces
pub const fn union(self, other: SurfaceColorSpaces) -> SurfaceColorSpaces
The bitwise or (|) of the bits in self and other.
pub const fn difference(self, other: SurfaceColorSpaces) -> SurfaceColorSpaces
pub const fn difference(self, other: SurfaceColorSpaces) -> SurfaceColorSpaces
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(
self,
other: SurfaceColorSpaces,
) -> SurfaceColorSpaces
pub const fn symmetric_difference( self, other: SurfaceColorSpaces, ) -> SurfaceColorSpaces
The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> SurfaceColorSpaces
pub const fn complement(self) -> SurfaceColorSpaces
The bitwise negation (!) of the bits in self, truncating the result.
impl SurfaceColorSpaces
impl SurfaceColorSpaces
pub const fn iter(&self) -> Iter<SurfaceColorSpaces>
pub const fn iter(&self) -> Iter<SurfaceColorSpaces>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<SurfaceColorSpaces>
pub const fn iter_names(&self) -> IterNames<SurfaceColorSpaces>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.