Type Definition wgpu::ImageCopyBuffer [−][src]
pub type ImageCopyBuffer<'a> = ImageCopyBufferBase<&'a Buffer>;Expand description
View of a buffer which can be used to copy to/from a texture.
pub type ImageCopyBuffer<'a> = ImageCopyBufferBase<&'a Buffer>;View of a buffer which can be used to copy to/from a texture.