align_to

Function align_to 

pub fn align_to<T>(value: T, alignment: T) -> T
where T: AlignTo,
Aligns a value to an alignment.

Returns the first number greater than or equal to value that is also a multiple of alignment. If value is already a multiple of alignment, value will be returned.

Panics

If aligning value to alignment would overflow.

Examples

assert_eq!(align_to(253_u32, 16), 256);
assert_eq!(align_to(256_u32, 16), 256);
assert_eq!(align_to(0_u32, 16), 0);