Struct wgpu::RenderPipeline [−][src]
Handle to a rendering (graphics) pipeline.
A RenderPipeline object represents a graphics pipeline and its stages, bindings, vertex
buffers and targets. A RenderPipeline may be created with Device::create_render_pipeline.
Implementations
impl RenderPipeline[src]
pub fn get_bind_group_layout(&self, index: u32) -> BindGroupLayout[src]
Get an object representing the bind group layout at a given index.