#[repr(C)]pub struct ShaderStages {
pub features_webgpu: ShaderStagesWebGPU,
pub features_wgpu: ShaderStagesWGPU,
}Expand description
Describes the shader stages that a binding will be visible from.
These can be combined so something that is visible from both vertex and fragment shaders can be defined as:
ShaderStages::VERTEX | ShaderStages::FRAGMENT
Corresponds to WebGPU GPUShaderStageFlags.
Fields
features_webgpu: ShaderStagesWebGPUfeatures_wgpu: ShaderStagesWGPUImplementations
Sourceimpl ShaderStages
impl ShaderStages
Sourcepub const NONE: ShaderStages
pub const NONE: ShaderStages
Binding is not visible from any shader stage.
Sourcepub const VERTEX: ShaderStages
pub const VERTEX: ShaderStages
Binding is visible from the vertex shader of a render pipeline.
Sourcepub const FRAGMENT: ShaderStages
pub const FRAGMENT: ShaderStages
Binding is visible from the fragment shader of a render pipeline.
Sourcepub const COMPUTE: ShaderStages
pub const COMPUTE: ShaderStages
Binding is visible from the compute shader of a compute pipeline.
Sourcepub const VERTEX_FRAGMENT: ShaderStages
pub const VERTEX_FRAGMENT: ShaderStages
Binding is visible from the vertex and fragment shaders of a render pipeline.
Sourcepub const TASK: ShaderStages
pub const TASK: ShaderStages
Binding is visible from the task shader of a mesh pipeline.
Sourcepub const MESH: ShaderStages
pub const MESH: ShaderStages
Binding is visible from the mesh shader of a mesh pipeline.
Sourcepub const RAY_GENERATION: ShaderStages
pub const RAY_GENERATION: ShaderStages
Binding is visible from the ray generation shader of a ray tracing pipeline.
Sourcepub const ANY_HIT: ShaderStages
pub const ANY_HIT: ShaderStages
Binding is visible from the ray any hit shader of a ray tracing pipeline.
Sourcepub const CLOSEST_HIT: ShaderStages
pub const CLOSEST_HIT: ShaderStages
Binding is visible from the ray closest hit shader of a ray tracing pipeline.
Sourcepub const MISS: ShaderStages
pub const MISS: ShaderStages
Binding is visible from the ray miss shader of a ray tracing pipeline.
Sourcepub const fn bits(&self) -> ShaderStagesBits
pub const fn bits(&self) -> ShaderStagesBits
Gets the set flags as a container holding an array of bits.
Sourcepub const fn empty() -> ShaderStages
pub const fn empty() -> ShaderStages
Returns self with no flags set.
Sourcepub const fn all() -> ShaderStages
pub const fn all() -> ShaderStages
Returns self with all flags set.
Sourcepub const fn contains(self, other: ShaderStages) -> bool
pub const fn contains(self, other: ShaderStages) -> bool
Whether all the bits set in other are all set in self
Sourcepub const fn intersects(self, other: ShaderStages) -> bool
pub const fn intersects(self, other: ShaderStages) -> bool
Returns whether any bit set in self matched any bit set in other.
Sourcepub const fn union(self, other: ShaderStages) -> ShaderStages
pub const fn union(self, other: ShaderStages) -> ShaderStages
Bitwise or - self | other
Sourcepub const fn intersection(self, other: ShaderStages) -> ShaderStages
pub const fn intersection(self, other: ShaderStages) -> ShaderStages
Bitwise and - self & other
Sourcepub const fn difference(self, other: ShaderStages) -> ShaderStages
pub const fn difference(self, other: ShaderStages) -> ShaderStages
Bitwise and of the complement of other - self & !other
Sourcepub const fn symmetric_difference(self, other: ShaderStages) -> ShaderStages
pub const fn symmetric_difference(self, other: ShaderStages) -> ShaderStages
Bitwise xor - self ^ other
Sourcepub const fn complement(self) -> ShaderStages
pub const fn complement(self) -> ShaderStages
Bitwise not - !self
Sourcepub fn set(&mut self, other: ShaderStages, set: bool)
pub fn set(&mut self, other: ShaderStages, set: bool)
Calls Self::insert if set is true and otherwise calls Self::remove.
Sourcepub fn insert(&mut self, other: ShaderStages)
pub fn insert(&mut self, other: ShaderStages)
Inserts specified flag(s) into self
Sourcepub fn remove(&mut self, other: ShaderStages)
pub fn remove(&mut self, other: ShaderStages)
Removes specified flag(s) from self
Sourcepub fn toggle(&mut self, other: ShaderStages)
pub fn toggle(&mut self, other: ShaderStages)
Toggles specified flag(s) in self
Sourcepub const fn from_bits(bits: ShaderStagesBits) -> Option<ShaderStages>
pub const fn from_bits(bits: ShaderStagesBits) -> Option<ShaderStages>
Takes in ShaderStagesBits and returns
None if there are invalid bits or otherwise Self with those bits set
Sourcepub const fn from_bits_truncate(bits: ShaderStagesBits) -> ShaderStages
pub const fn from_bits_truncate(bits: ShaderStagesBits) -> ShaderStages
Takes in ShaderStagesBits and returns Self with only valid bits (all other bits removed)
Sourcepub const fn from_bits_retain(bits: ShaderStagesBits) -> ShaderStages
pub const fn from_bits_retain(bits: ShaderStagesBits) -> ShaderStages
Takes in ShaderStagesBits and returns Self with all bits that were set without removing invalid bits
Sourcepub fn from_name(name: &str) -> Option<ShaderStages>
pub fn from_name(name: &str) -> Option<ShaderStages>
Takes in a bitflags flag name (in SCREAMING_SNAKE_CASE) and returns Self
if it matches or none if the name does not match the name of any of the
flags. Name is capitalisation dependent.
[impl FromStr] can be used to recognize kebab-case names, like are used in
the WebGPU spec.
Sourcepub fn from_internal_flags(
features_webgpu: ShaderStagesWebGPU,
features_wgpu: ShaderStagesWGPU,
) -> ShaderStages
pub fn from_internal_flags( features_webgpu: ShaderStagesWebGPU, features_wgpu: ShaderStagesWGPU, ) -> ShaderStages
Combines the flags from the internal flags into the entire flags struct
Sourcepub const fn iter(&self) -> Iter<ShaderStages>
pub const fn iter(&self) -> Iter<ShaderStages>
Returns an iterator over the set flags.
Sourcepub const fn iter_names(&self) -> IterNames<ShaderStages>
pub const fn iter_names(&self) -> IterNames<ShaderStages>
Returns an iterator over the set flags and their names.
These are bitflags names in SCREAMING_SNAKE_CASE.